@@ -1,8 +1,6 @@
 from fastapi import Depends, HTTPException, status
 
 from a360_security.enums.role import Role
-from .user_dependant import require_user
-from ..dto import UserDTO
 from ..role_hierarchy import has_role
 from ..utils.aws_cognito import AWSCognitoService, get_aws_cognito
 from ..utils.bearer import get_token
@@ -25,15 +23,3 @@ def require_role(*required_roles: Role):
                 detail=f"Insufficient permissions: requires one of {roles_str}"
             )
     return role_checker
-
-
-def is_practice_dependant_role(
-        user: UserDTO = Depends(require_user)
-) -> bool:
-    practice_dependent_roles = [
-        Role.PRACTICE_SECRETARY,
-        Role.PRACTICE_ADMIN,
-        Role.PRACTICE_DOCTOR,
-        Role.PRACTICE_OFFICE_ADMIN,
-    ]
-    return any(role in practice_dependent_roles for role in user.roles)
