@@ -54,9 +54,22 @@ class DictionaryService:
             request_path=request_path
         ).get('items')
 
-    def get_tag_categories(self, service_name: str) -> dict:
-        query_params = {'service_name': service_name}
+    def get_tag_categories(
+            self,
+            search: str = None,
+            is_core: bool = None,
+            is_active: bool = None) -> dict:
+        query_params = {}
+
+        if search is not None:
+            query_params['search'] = search
+        if is_core is not None:
+            query_params['is_core'] = is_core
+        if is_active is not None:
+            query_params['is_active'] = is_active
+
         request_path = f"/tag_categories?{urlencode(query_params, doseq=True)}"
+
         return self.service_provider.fetch_data(
             service=Services.dict,
             request_path=request_path
@@ -71,11 +84,14 @@ class DictionaryService:
 
     def get_tags(self, search: str = None, is_active: bool = None) -> dict:
         query_params = {}
-        if search:
+
+        if search is not None:
             query_params['search'] = search
         if is_active is not None:
             query_params['is_active'] = is_active
-        request_path = f"/tags?{urlencode(query_params)}"
+
+        request_path = f"/tags?{urlencode(query_params, doseq=True)}"
+
         return self.service_provider.fetch_data(
             service=Services.dict,
             request_path=request_path
